@@ -1,4 +1,4 @@
-﻿from dataclasses import InitVar, dataclass, field
+from dataclasses import InitVar, dataclass, field
 from typing import Optional, Union, List
 
 from mlbstatsapi.models.people import Person, Pitcher, Batter
@@ -150,8 +150,13 @@ class SimplePitchingSplit:
         The number of inherited runners scored by the pitcher.
     inheritedrunners : int
         The number of inherited runners for the pitcher.
+    age : int
+        The age of the pitcher.
+    caughtstealingpercentage : str
+        The caught stealing percentage for the pitcher.
     """
     summary: Optional[str] = None
+    age: Optional[int] = None
     gamesplayed: Optional[int] = None
     gamesstarted: Optional[int] = None
     flyouts: Optional[int] = None
@@ -172,6 +177,7 @@ class SimplePitchingSplit:
     slg: Optional[str] = None
     ops: Optional[str] = None
     caughtstealing: Optional[int] = None
+    caughtstealingpercentage: Optional[str]=None
     stolenbases: Optional[int] = None
     stolenbasepercentage: Optional[str] = None
     groundintodoubleplay: Optional[int] = None
@@ -216,6 +222,8 @@ class SimplePitchingSplit:
     balls: Optional[int] = None
     outspitched: Optional[int] = None
     rbi: Optional[int] = None
+    age: Optional[int] = None
+    caughtstealingpercentage: Optional[str] = None
 
     def __repr__(self) -> str:
         kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None and value]
@@ -327,6 +335,7 @@ class AdvancedPitchingSplit:
         The number of bequeathed runners scored.
         see also: https://www.mlb.com/glossary/advanced-stats/bequeathed-runners
     """
+    age: Optional[int] = None
     winningpercentage: Optional[str] = None
     runsscoredper9: Optional[str] = None
     battersfaced: Optional[int] = None
@@ -352,6 +361,12 @@ class AdvancedPitchingSplit:
     pickoffs: Optional[int] = None
     totalswings: Optional[int] = None
     swingandmisses: Optional[int] = None
+    strikeoutsminuswalkspercentage: Optional[str] = None
+    gidppercentage: Optional[str] = None
+    battersfacedpergame: Optional[str] = None
+    buntsfailed: Optional[int] = None
+    buntsmissedtipped: Optional[int] = None
+    whiffpercentage: Optional[int] = None
     ballsinplay: Optional[int] = None
     runsupport: Optional[int] = None
     strikepercentage: Optional[str] = None
@@ -374,6 +389,9 @@ class AdvancedPitchingSplit:
     inheritedrunnersscored: Optional[int] = None
     bequeathedrunners: Optional[int] = None
     bequeathedrunnersscored: Optional[int] = None
+    inningspitchedpergame: Optional[str] = None
+    flyballpercentage: Optional[str] = None
+
 
     def __repr__(self) -> str:
         kws = [f'{key}={value}' for key, value in self.__dict__.items() if value is not None and value]
